@@ -31,13 +31,13 @@
 
 #include "kpToolPolygonalBase.h"
 
-#include <float.h>
-#include <math.h>
+#include <cfloat>
+#include <QtMath>
 
-#include <qcursor.h>
-#include <qpoint.h>
-#include <qpolygon.h>
-#include <qrect.h>
+#include <QCursor>
+#include <QPoint>
+#include <QPolygon>
+#include <QRect>
 
 #include <KLocalizedString>
 
@@ -113,8 +113,8 @@ void kpToolPolygonalBase::begin ()
 #endif
 
     d->toolWidgetLineWidth = tb->toolWidgetLineWidth ();
-    connect (d->toolWidgetLineWidth, SIGNAL (lineWidthChanged(int)),
-                this, SLOT (updateShape()));
+    connect (d->toolWidgetLineWidth, &kpToolWidgetLineWidth::lineWidthChanged,
+             this, &kpToolPolygonalBase::updateShape);
     d->toolWidgetLineWidth->show ();
 
     viewManager ()->setCursor (QCursor (Qt::ArrowCursor));
@@ -132,10 +132,8 @@ void kpToolPolygonalBase::end ()
     // TODO: needed?
     endShape ();
 
-    disconnect (d->toolWidgetLineWidth,
-        SIGNAL (lineWidthChanged(int)),
-        this,
-        SLOT (updateShape()));
+    disconnect (d->toolWidgetLineWidth, &kpToolWidgetLineWidth::lineWidthChanged,
+             this, &kpToolPolygonalBase::updateShape);
     d->toolWidgetLineWidth = nullptr;
 
     viewManager ()->unsetCursor ();
@@ -146,7 +144,7 @@ void kpToolPolygonalBase::beginDraw ()
 {
 #if DEBUG_KP_TOOL_POLYGON
     qCDebug(kpLogTools) << "kpToolPolygonalBase::beginDraw()  d->points=" << d->points.toList ()
-               << ", startPoint=" << startPoint () << endl;
+               << ", startPoint=" << startPoint ();
 #endif
 
     bool endedShape = false;
@@ -206,8 +204,7 @@ void kpToolPolygonalBase::applyModifiers ()
                << " endPt=" << lineEndPoint
                << "   modifiers: shift=" << shiftPressed ()
                << "   alt=" << altPressed ()
-               << "   ctrl=" << controlPressed ()
-               << endl;
+               << "   ctrl=" << controlPressed ();
 #endif
 
     // angles
@@ -217,14 +214,15 @@ void kpToolPolygonalBase::applyModifiers ()
         int diffy = lineEndPoint.y () - lineStartPoint.y ();
 
         double ratio;
-        if (diffx == 0)
+        if (diffx == 0) {
             ratio = DBL_MAX;
-        else
+        }
+        else {
             ratio = fabs (double (diffy) / double (diffx));
+        }
     #if DEBUG_KP_TOOL_POLYGON && 1
         qCDebug(kpLogTools) << "\tdiffx=" << diffx << " diffy=" << diffy
-                   << " ratio=" << ratio
-                   << endl;
+                   << " ratio=" << ratio;
     #endif
 
         // Shift        = 0, 45, 90
@@ -233,19 +231,22 @@ void kpToolPolygonalBase::applyModifiers ()
         double angles [10];  // "ought to be enough for anybody"
         int numAngles = 0;
         angles [numAngles++] = 0;
-        if (controlPressed ())
-            angles [numAngles++] = KP_PI / 6;
-        if (shiftPressed ())
-            angles [numAngles++] = KP_PI / 4;
-        if (controlPressed ())
-            angles [numAngles++] = KP_PI / 3;
-        angles [numAngles++] = KP_PI / 2;
+        if (controlPressed ()) {
+            angles [numAngles++] = M_PI / 6;
+        }
+        if (shiftPressed ()) {
+            angles [numAngles++] = M_PI / 4;
+        }
+        if (controlPressed ()) {
+            angles [numAngles++] = M_PI / 3;
+        }
+        angles [numAngles++] = M_PI / 2;
         Q_ASSERT (numAngles <= int (sizeof (angles) / sizeof (angles [0])));
 
         double angle = angles [numAngles - 1];
         for (int i = 0; i < numAngles - 1; i++)
         {
-            double acceptingRatio = tan ((angles [i] + angles [i + 1]) / 2.0);
+            double acceptingRatio = std::tan ((angles [i] + angles [i + 1]) / 2.0);
             if (ratio < acceptingRatio)
             {
                 angle = angles [i];
@@ -254,14 +255,14 @@ void kpToolPolygonalBase::applyModifiers ()
         }
 
         // horizontal (dist from start not maintained)
-        if (fabs (KP_RADIANS_TO_DEGREES (angle) - 0)
+        if (std::fabs (qRadiansToDegrees (angle) - 0)
             < kpPixmapFX::AngleInDegreesEpsilon)
         {
             lineEndPoint =
                 QPoint (lineEndPoint.x (), lineStartPoint.y ());
         }
         // vertical (dist from start not maintained)
-        else if (fabs (KP_RADIANS_TO_DEGREES (angle) - 90)
+        else if (std::fabs (qRadiansToDegrees (angle) - 90)
                  < kpPixmapFX::AngleInDegreesEpsilon)
         {
             lineEndPoint =
@@ -270,7 +271,7 @@ void kpToolPolygonalBase::applyModifiers ()
         // diagonal (dist from start maintained)
         else
         {
-            const double dist = sqrt ((double)(diffx * diffx + diffy * diffy));
+            const double dist = std::sqrt (static_cast<double> (diffx * diffx + diffy * diffy));
 
             #define sgn(a) ((a)<0?-1:1)
             // Round distances _before_ adding to any coordinate
@@ -284,9 +285,8 @@ void kpToolPolygonalBase::applyModifiers ()
 
         #if DEBUG_KP_TOOL_POLYGON && 1
             qCDebug(kpLogTools) << "\t\tdiagonal line: dist=" << dist
-                       << " angle=" << (angle * 180 / KP_PI)
-                       << " endPoint=" << lineEndPoint
-                       << endl;
+                       << " angle=" << (angle * 180 / M_PI)
+                       << " endPoint=" << lineEndPoint;
         #endif
         }
     }    // if (shiftPressed () || controlPressed ()) {
@@ -298,10 +298,12 @@ void kpToolPolygonalBase::applyModifiers ()
         //       = start - (end - start)
         //       = start - end + start
         //       = 2 * start - end
-        if (count == 2)
+        if (count == 2) {
             lineStartPoint += (lineStartPoint - lineEndPoint);
-        else
+        }
+        else {
             lineEndPoint += (lineEndPoint - lineStartPoint);
+        }
     }    // if (altPressed ()) {
 }
 
@@ -328,12 +330,13 @@ void kpToolPolygonalBase::draw (const QPoint &, const QPoint &, const QRect &)
     // another control point) would have caused endShape() to have been
     // called in kpToolPolygonalBase::beginDraw().  The points list would now
     // be empty.  We are being called by kpTool::mouseReleaseEvent().
-    if (d->points.count () == 0)
+    if (d->points.count () == 0) {
         return;
+    }
 
 #if DEBUG_KP_TOOL_POLYGON
     qCDebug(kpLogTools) << "kpToolPolygonalBase::draw()  d->points=" << d->points.toList ()
-               << ", endPoint=" << currentPoint () << endl;
+               << ", endPoint=" << currentPoint ();
 #endif
 
     // Update points() so that last point reflects current mouse position.
@@ -387,8 +390,9 @@ kpColor kpToolPolygonalBase::drawingBackgroundColor () const
 // protected slot
 void kpToolPolygonalBase::updateShape ()
 {
-    if (d->points.count () == 0)
+    if (d->points.count () == 0) {
         return;
+    }
 
     const QRect boundingRect = kpTool::neededRect (
             d->points.boundingRect (),
@@ -436,8 +440,9 @@ void kpToolPolygonalBase::cancelShape ()
 
 void kpToolPolygonalBase::releasedAllButtons ()
 {
-    if (!hasBegunShape ())
+    if (!hasBegunShape ()) {
         setUserMessage (/*virtual*/haventBegunShapeUserMessage ());
+    }
 
     // --- else case already handled by endDraw() ---
 }
@@ -450,8 +455,9 @@ void kpToolPolygonalBase::endShape (const QPoint &, const QRect &)
         << d->points.toList () << endl;
 #endif
 
-    if (!hasBegunShape ())
+    if (!hasBegunShape ()) {
         return;
+    }
 
     viewManager ()->invalidateTempImage ();
 
